const { ipcMain, dialog } = require("electron");
const { spawn } = require("child_process");
const { basename, join, posix } = require("path");
const { copyFileSync } = require("fs");

const handler = win => {
  ipcMain.on("terminal", (_, data) => {
    if (process.platform === "win32") {
      spawn("cmd", ["/c", "start", "docker", "exec", "-it", data, "bash"]);
    } else {
      spawn("exo-open", [
        "--launch",
        "TerminalEmulator",
        "docker",
        "exec",
        "-it",
        data,
        "bash"
      ]);
    }
  });
  ipcMain.on("viewer", (_, data) => {
    const { Port, Name } = data;
    spawn("remote-viewer", [`spice://localhost:${Port}`, "-f", "-t", Name]);
  });
  ipcMain.on("upload", (_, data) => {
    const { Id, Name, Source, Target, Username } = data;
    dialog
      .showOpenDialog({
        properties: ["openFile", "multiSelections"]
      })
      .then(result => {
        if (result.canceled) {
          return;
        }
        result.filePaths.map(f => {
          copyFileSync(f, join(Source, basename(f)));
          spawn("docker", [
            "exec",
            Id,
            "cp",
            "-r",
            `${posix.join(Target, basename(f))}`,
            `/home/${Username}/Desktop/`
          ]);
          spawn("docker", [
            "exec",
            Id,
            "chown",
            `${Username}:${Username}`,
            `/home/${Username}/Desktop/${basename(f)}`
          ]);
          if (win && win.webContents) {
            win.webContents.executeJavaScript(
              `window.dispatchEvent(new CustomEvent('uploaded', { detail: {success: true, file: '${basename(
                basename(f)
              )}', container: '${Name}'}}));`
            );
          }
        });
      })
      .catch(() => {
        if (win && win.webContents) {
          win.webContents.executeJavaScript(
            `window.dispatchEvent(new CustomEvent('uploaded', { detail: {success: false, file: '', container: '${Name}'}}));`
          );
        }
      });
  });
};

module.exports = handler;
